
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef MPC_controller_MSG_LIB_H
#define MPC_controller_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "MPC_controllerType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  MPC_CONTROLLER_MBOX_NAME                  genomInstanceName("MPC_controller")

#define  MPC_CONTROLLER_MAX_RQST_SIZE              768

#define  MPC_CONTROLLER_MBOX_RQST_SIZE       \
 (BUF_SIZE(MPC_CONTROLLER_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  MPC_CONTROLLER_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  MPC_CONTROLLER_MAX_REPLY_SIZE             8

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  MPC_CONTROLLER_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(MPC_CONTROLLER_MAX_REPLY_SIZE) \
   + BUF_SIZE(MPC_CONTROLLER_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define MPC_CONTROLLER_INIT_RQST 0
#define MPC_CONTROLLER_GOTO_RQST 1
#define MPC_CONTROLLER_SETMANASYS_RQST 2
#define MPC_CONTROLLER_STOP_RQST 3
#define MPC_CONTROLLER_TRACKCTRAJ_RQST 4
#define MPC_CONTROLLER_STOPCTRAJTRACK_RQST 5
#define MPC_CONTROLLER_ABORT_RQST 6


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS MPC_controllerClientInit (CLIENT_ID *pClientId);

STATUS MPC_controllerClientEnd (CLIENT_ID clientId);

int MPC_controllerAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int MPC_controllerAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int MPC_controllerAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS MPC_controllerInitRqstSend (CLIENT_ID clientId, int *pRqstId,
					 INIT_I *(in_Init_I),
					 int replyTimeOut);

extern int MPC_controllerInitReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_controllerInitRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					INIT_I *(in_Init_I), 
					
					int *activity, int *bilan);

extern int MPC_controllerInitRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					INIT_I *(in_Init_I), 
					
					int *activity,
					int *bilan);




extern STATUS MPC_controllerGoToRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GOTO_I *(in_Goto_I),
					 int replyTimeOut);

extern int MPC_controllerGoToReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_controllerGoToRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GOTO_I *(in_Goto_I), 
					
					int *activity, int *bilan);

extern int MPC_controllerGoToRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GOTO_I *(in_Goto_I), 
					
					int *activity,
					int *bilan);




extern STATUS MPC_controllerSetManaSysRqstSend (CLIENT_ID clientId, int *pRqstId,
					 SETMANASYS_I *(in_SetManaSys_I),
					 int replyTimeOut);

extern int MPC_controllerSetManaSysReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_controllerSetManaSysRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					SETMANASYS_I *(in_SetManaSys_I), 
					
					int *activity, int *bilan);

extern int MPC_controllerSetManaSysRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					SETMANASYS_I *(in_SetManaSys_I), 
					
					int *activity,
					int *bilan);




extern STATUS MPC_controllerStopRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int MPC_controllerStopReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_controllerStopRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int MPC_controllerStopRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS MPC_controllerTrackCTrajRqstSend (CLIENT_ID clientId, int *pRqstId,
					 TRACKCTRAJ_I *(in_TrackCTraj_I),
					 int replyTimeOut);

extern int MPC_controllerTrackCTrajReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int MPC_controllerTrackCTrajRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					TRACKCTRAJ_I *(in_TrackCTraj_I), 
					
					int *activity, int *bilan);

extern int MPC_controllerTrackCTrajRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					TRACKCTRAJ_I *(in_TrackCTraj_I), 
					
					int *activity,
					int *bilan);




extern STATUS MPC_controllerStopCTrajTrackRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int MPC_controllerStopCTrajTrackReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int MPC_controllerStopCTrajTrackRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* MPC_controller_MSG_LIB_H */

